# configuration files
%global dhcpconfdir %{_sysconfdir}/dhcp

%global patchver P1
%global DHCPVERSION %{version}%{?patchver:-%{patchver}}

Summary:  Dynamic host configuration protocol software
Name:     dhcp
Version:  4.4.3
Release:  6%{?patchver:.%patchver}%{?dist}
License:  ISC and MPLv2.0
Url:      https://www.isc.org/dhcp/
Source0:  https://downloads.isc.org/isc/dhcp/%{DHCPVERSION}/dhcp-%{DHCPVERSION}.tar.gz
Source1:  dhclient-script
Source2:  README.dhclient.d
Source3:  11-dhclient
Source4:  dhcpd.service
Source5:  dhcpd6.service
Source6:  dhcrelay.service
Source7:  dhcpd
Source8:  dhcpd.conf
Source9: dhcpd6.conf
Source10:  dhclient-enter-hooks


Patch3000: 0002-additional-dhclient-options.patch
Patch3001: 0004-Support-unicast-BOOTP-for-IBM-pSeries-systems-and-ma.patch
Patch3002: 0005-Change-default-requested-options.patch
Patch3003: 0006-Various-man-page-only-fixes.patch
Patch3004: 0007-Change-paths-to-conform-to-our-standards.patch
Patch3005: 0008-Make-sure-all-open-file-descriptors-are-closed-on-ex.patch
Patch3006: 0009-Fix-garbage-in-format-string-error.patch
Patch3007: 0011-Drop-unnecessary-capabilities.patch
Patch3008: 0012-RFC-3442-Classless-Static-Route-Option-for-DHCPv4-51.patch
Patch3009: 0013-DHCPv6-over-PPP-support-626514.patch
Patch3010: 0014-IPoIB-support-660681.patch
Patch3011: 0015-Add-GUID-DUID-to-dhcpd-logs-1064416.patch
Patch3012: 0016-Turn-on-creating-sending-of-DUID.patch
Patch3013: 0017-Send-unicast-request-release-via-correct-interface.patch
Patch3014: 0018-No-subnet-declaration-for-iface-should-be-info-not-e.patch
Patch3015: 0020-Discover-all-hwaddress-for-xid-uniqueness.patch
Patch3016: 0021-Load-leases-DB-in-non-replay-mode-only.patch
Patch3017: 0022-dhclient-make-sure-link-local-address-is-ready-in-st.patch
Patch3018: 0023-option-97-pxe-client-id.patch
Patch3019: 0024-Detect-system-time-changes.patch
Patch3020: 0025-bind-Detect-system-time-changes.patch
Patch3021: 0026-Add-dhclient-5-B-option-description.patch
Patch3022: 0027-Add-missed-sd-notify-patch-to-manage-dhcpd-with-syst.patch
Patch3023: 0028-Use-system-getaddrinfo-for-dhcp.patch
Patch3024: CVE-2021-25220.patch

BuildRequires: autoconf automake make libtool
# --with-ldap-gssapi 
BuildRequires: openldap-devel
BuildRequires: krb5-devel libcap-ng-devel
BuildRequires: systemd systemd-devel pkgconfig(libsystemd)


# prevent _docdir to introduce wrong requirement
# https://bugzilla.redhat.com/show_bug.cgi?id=674058
%filter_requires_in %{_docdir}
%{filter_setup}


%description
ISC DHCP (Dynamic Host Configuration Protocol) suite.


%package server
Summary: Provides the ISC DHCP server
Requires: %{name}-common = %{version}-%{release}
Obsoletes: %{name}-compat < 4.4.2-12.b1
Requires(pre): shadow-utils
Requires(post): coreutils grep sed
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description server
This package provides the ISC DHCP (Dynamic Host Configuration Protocol) Server
which allows individual devices on an IP network to get their own network
configuration information.


%package relay
Summary: Provides the ISC DHCP relay agent
Requires: %{name}-common = %{version}-%{release}
Obsoletes: %{name}-compat < 4.4.2-12.b1
Requires(post): grep sed
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description relay
This package provides the ISC DHCP relay agent which
passes DHCP requests from one LAN to another, so that 
a DHCP server is not needed on every LAN.


%package client
Summary: Provides the ISC DHCP client daemon and dhclient-script
Provides: dhclient = %{version}-%{release}
Obsoletes: dhclient < %{version}-%{release}
Requires: coreutils gawk grep ipcalc iproute iputils sed systemd
Requires: %{name}-common = %{version}-%{release}

%description client
This package provides the ISC DHCP client which can be bundled with 
the operating system of a client computer or other IP capable device; 
DHCP client sends configuration requests to the server. 


%package common
Summary: Common files used by ISC dhcp client, server and relay agent
BuildArch: noarch
Obsoletes: dhcp-libs < %{version}

%description common
This package provides common files used by dhcp and dhclient package.


%package libs-static
Summary: Shared libraries used by ISC dhcp client and server
Provides: %{name}-libs = %{version}-%{release}
Provides: %{name}-libs = %{version}-%{release}
Provides: bundled(bind-export-libs)
Provides: bundled(bind)

%description libs-static
This package contains shared libraries used by ISC dhcp client and server.


%package devel
Summary: Development headers and libraries for interfacing to the DHCP server
Requires: %{name}-libs = %{version}-%{release}

%description devel
Header files and API documentation for using the ISC DHCP libraries. The
libdhcpctl and libomapi static libraries are also included in this package.


%prep
%setup -n dhcp-%{DHCPVERSION}
pushd bind
tar -xvf bind.tar.gz
popd
%autopatch -p1


for page in client/dhclient.conf.5 client/dhclient.leases.5 \
            client/dhclient-script.8 client/dhclient.8 ; do
    sed -i 's|CLIENTBINDIR|%{_sbindir}|g' $page
    sed -i 's|RUNDIR|%{_localstatedir}/run|g' $page
    sed -i 's|DBDIR|%{_localstatedir}/lib/dhclient|g' $page
    sed -i 's|ETCDIR|%{dhcpconfdir}|g' $page 
done

for page in server/dhcpd.conf.5 server/dhcpd.leases.5 server/dhcpd.8 ; do
    sed -i 's|CLIENTBINDIR|%{_sbindir}|g' $page
    sed -i 's|RUNDIR|%{_localstatedir}/run|g' $page
    sed -i 's|DBDIR|%{_localstatedir}/lib/dhcpd|g' $page
    sed -i 's|ETCDIR|%{dhcpconfdir}|g' $page
done

sed -i 's|/var/db/|%{_localstatedir}/lib/dhcpd/|g' contrib/dhcp-lease-list.pl


%build
autoreconf -fiv

CFLAGS="%{optflags} -fno-strict-aliasing -fcommon" \
%configure \
    --with-srv-lease-file=%{_localstatedir}/lib/dhcpd/dhcpd.leases \
    --with-srv6-lease-file=%{_localstatedir}/lib/dhcpd/dhcpd6.leases \
    --with-cli-lease-file=%{_localstatedir}/lib/dhclient/dhclient.leases \
    --with-cli6-lease-file=%{_localstatedir}/lib/dhclient/dhclient6.leases \
    --with-srv-pid-file=%{_localstatedir}/run/dhcpd.pid \
    --with-srv6-pid-file=%{_localstatedir}/run/dhcpd6.pid \
    --with-cli-pid-file=%{_localstatedir}/run/dhclient.pid \
    --with-cli6-pid-file=%{_localstatedir}/run/dhclient6.pid \
    --with-relay-pid-file=%{_localstatedir}/run/dhcrelay.pid \
    --with-ldap \
    --with-ldapcrypto \
    --with-ldap-gssapi \
    --enable-log-pid \
    --enable-paranoia --enable-early-chroot \
    --enable-binary-leases \
    --with-systemd
make -j1


%install
%make_install %{?_smp_mflags}

rm -f %{buildroot}%{_sysconfdir}/dhclient.conf.example
rm -f %{buildroot}%{_sysconfdir}/dhcpd.conf.example

install -D -p -m 0755 %{SOURCE1} %{buildroot}%{_sbindir}/dhclient-script
install -p -m 0644 %{SOURCE2} .
mkdir -p %{buildroot}%{dhcpconfdir}/dhclient.d

install -D -p -m 0755 %{SOURCE3} %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d/11-dhclient

install -D -m 644 -t %{buildroot}%{_unitdir} %{SOURCE4} %{SOURCE5} %{SOURCE6} 

mkdir -p %{buildroot}%{_localstatedir}/lib/{dhcpd,dhclient}
touch %{buildroot}%{_localstatedir}/lib/dhcpd/{dhcpd.leases,dhcpd6.leases}
touch %{buildroot}%{_localstatedir}/lib/dhcpd/

install -D -p -m 0755 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/dhcpd
install -p -m 0644 %{SOURCE8} %{SOURCE9} %{buildroot}%{dhcpconfdir}
install -p -m 0644 %{SOURCE10} client/dhclient-enter-hooks

install -D -p -m 0644 contrib/ldap/dhcp.schema %{buildroot}%{_sysconfdir}/openldap/schema/dhcp.schema

cp -p doc/examples/dhclient-dhcpv6.conf client/dhclient6.conf.example
cp -p doc/examples/dhcpd-dhcpv6.conf server/dhcpd6.conf.example


find %{buildroot} -type f -name "*.la" -delete -print

%pre server
%global gid_uid 177
getent group dhcpd >/dev/null || groupadd --force --gid %{gid_uid} --system dhcpd
if ! getent passwd dhcpd >/dev/null ; then
    if ! getent passwd %{gid_uid} >/dev/null ; then
      useradd --system --uid %{gid_uid} --gid dhcpd --home / --shell /sbin/nologin --comment "DHCP server" dhcpd
    else
      useradd --system --gid dhcpd --home / --shell /sbin/nologin --comment "DHCP server" dhcpd
    fi
fi
: 

%post server
# install
%systemd_post dhcpd.service dhcpd6.service


%post relay
# install
%systemd_post dhcrelay.service


%preun server
# uninstall
if [ $1 -eq 0 ]; then
%systemd_preun dhcpd.service dhcpd6.service
fi

%preun relay
# uninstall
if [ $1 -eq 0 ]; then
%systemd_preun dhcrelay.service
fi

%postun server
# upgrade
if [ $1 -ge 1 ]; then
%systemd_postun_with_restart dhcpd.service dhcpd6.service
fi

%postun relay
# upgrade
if [ $1 -ge 1 ]; then
%systemd_postun_with_restart dhcrelay.service
fi


%files server
%doc server/dhcpd.conf.example server/dhcpd6.conf.example
%doc contrib/ldap/ contrib/dhcp-lease-list.pl
%attr(0750,root,root) %dir %{dhcpconfdir}
%attr(0755,dhcpd,dhcpd) %dir %{_localstatedir}/lib/dhcpd
%dir %{_sysconfdir}/openldap/schema
%attr(0644,root,root) %{_unitdir}/dhcpd.service
%attr(0644,root,root) %{_unitdir}/dhcpd6.service
%attr(0644,dhcpd,dhcpd) %verify(mode) %config(noreplace) %{_localstatedir}/lib/dhcpd/dhcpd.leases
%attr(0644,dhcpd,dhcpd) %verify(mode) %config(noreplace) %{_localstatedir}/lib/dhcpd/dhcpd6.leases
%config(noreplace) %{_sysconfdir}/sysconfig/dhcpd
%config(noreplace) %{_sysconfdir}/openldap/schema/dhcp.schema
%config(noreplace) %{dhcpconfdir}/dhcpd.conf
%config(noreplace) %{dhcpconfdir}/dhcpd6.conf
%{_sbindir}/dhcpd
%{_bindir}/omshell
%attr(0644,root,root) %{_mandir}/man1/omshell.1.gz
%attr(0644,root,root) %{_mandir}/man5/dhcpd.conf.5.gz
%attr(0644,root,root) %{_mandir}/man5/dhcpd.leases.5.gz
%attr(0644,root,root) %{_mandir}/man8/dhcpd.8.gz

%files relay
%{_sbindir}/dhcrelay
%attr(0644,root,root) %{_unitdir}/dhcrelay.service
%attr(0644,root,root) %{_mandir}/man8/dhcrelay.8.gz

%files client
%doc README.dhclient.d
%doc client/dhclient.conf.example client/dhclient6.conf.example client/dhclient-enter-hooks
%attr(0750,root,root) %dir %{dhcpconfdir}
%dir %{dhcpconfdir}/dhclient.d
%dir %{_localstatedir}/lib/dhclient
%dir %{_prefix}/lib/NetworkManager
%dir %{_prefix}/lib/NetworkManager/dispatcher.d
%{_prefix}/lib/NetworkManager/dispatcher.d/11-dhclient
%{_sbindir}/dhclient
%{_sbindir}/dhclient-script
%attr(0644,root,root) %{_mandir}/man5/dhclient.conf.5.gz
%attr(0644,root,root) %{_mandir}/man5/dhclient.leases.5.gz
%attr(0644,root,root) %{_mandir}/man8/dhclient.8.gz
%attr(0644,root,root) %{_mandir}/man8/dhclient-script.8.gz

%files common
%license LICENSE
%doc README RELNOTES doc/References.txt
%attr(0644,root,root) %{_mandir}/man5/dhcp-options.5.gz
%attr(0644,root,root) %{_mandir}/man5/dhcp-eval.5.gz

%files libs-static
%{_libdir}/libdhcp*.a
%{_libdir}/libomapi.a

%files devel
%doc doc/IANA-arp-parameters doc/api+protocol
%{_includedir}/dhcpctl
%{_includedir}/omapip
%attr(0644,root,root) %{_mandir}/man3/dhcpctl.3.gz
%attr(0644,root,root) %{_mandir}/man3/omapi.3.gz


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.3-6.P1
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.3-5.P1
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 29 2023 kianli <kianli@tencent.com> - 4.4.3-4.P1
- Upgrade to 4.4.3-P1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.3-2
- Rebuilt for OpenCloudOS Stream 23

* Thu May 12 2022 Yi Lin <nilusyi@tencent.com> - 4.4.3-1
- Package init.
